# What is pyGARL?
pyGARL stands for _Python Gesture Analysis and Recognition Library_ and, as you may expect, it's used to build gesture recognition systems.
I decided to build it because, after the success of my previous project ( the Gesture Keyboard ), I felt that a general purpose gesture recognition library would have been useful for a lot of people.

